from abc import ABC, abstractmethod

from cpl_query.extension import List

from bot_api.filter.auth_user_select_criteria import AuthUserSelectCriteria
from bot_api.model.auth_user_dto import AuthUserDTO
from bot_api.model.reset_password_dto import ResetPasswordDTO
from bot_api.model.token_dto import TokenDTO
from bot_api.model.update_auth_user_dto import UpdateAuthUserDTO
from bot_data.model.auth_user import AuthUser


class AuthABC(ABC):

    @abstractmethod
    def __init__(self): pass

    @abstractmethod
    async def get_all_auth_users_async(self) -> List[AuthUser]: pass

    @abstractmethod
    async def get_filtered_auth_users_async(self, criteria: AuthUserSelectCriteria) -> List[AuthUser]: pass

    @abstractmethod
    async def get_auth_user_by_email_async(self, email: str) -> AuthUser: pass

    @abstractmethod
    async def find_auth_user_by_email_async(self, email: str) -> AuthUser: pass

    @abstractmethod
    async def add_auth_user_async(self, user_dto: AuthUserDTO) -> AuthUser: pass

    @abstractmethod
    async def confirm_email_async(self, id: str) -> AuthUser: pass

    @abstractmethod
    async def login_async(self, user_dto: AuthUserDTO) -> AuthUser: pass

    @abstractmethod
    async def forgot_password_async(self, email: str) -> AuthUser: pass

    @abstractmethod
    async def confirm_forgot_password_async(self, id: str) -> AuthUser: pass

    @abstractmethod
    async def reset_password_async(self, rp_dto: ResetPasswordDTO) -> AuthUser: pass

    @abstractmethod
    async def update_user_async(self, update_user_dto: UpdateAuthUserDTO) -> AuthUser: pass

    @abstractmethod
    async def update_user_as_admin_async(self, update_user_dto: UpdateAuthUserDTO) -> AuthUser: pass

    @abstractmethod
    async def refresh_async(self, token_dto: TokenDTO) -> AuthUser: pass

    @abstractmethod
    async def revoke_async(self, token_dto: TokenDTO) -> AuthUser: pass

    @abstractmethod
    async def delete_auth_user_by_email_async(self, email: str) -> AuthUser: pass

    @abstractmethod
    async def delete_auth_user_async(self, user_dto: AuthUserDTO) -> AuthUser: pass
